# Examples of calculating phylogentic signals using delta statistics (Borges et al., 2019)
# https://doi.org/10.1093/bioinformatics/bty800
# Taking mycorrhizal type, AM and ERM as examples

library("ape") 
source("deltaFunction.R")

#SOME PARAMETERS... 
lambda0 <- 0.1   #rate parameter of the proposal 
se      <- 0.5   #standard deviation of the proposal
sim     <- 100000 #number of iterations
thin    <- 50    #we kept only each 10th iterate 
burn    <- 10000   #100 iterates are burned-in

# cut tips to the final 11770 species
supertree <- readRDS("7_Myco.plant.supertree.output_v3.rds")

fulldata <- read.csv("11770.csv",encoding = "UTF-8", row.names = 1)

spmatch <- match(supertree$scenario.3$tip.label,
                 fulldata[,1])
myco.tree <- drop.tip(supertree$scenario.3,
                      supertree$scenario.3$tip.label[is.na(spmatch)])
cbind(myco.tree$tip.label,fulldata[,1])
spmatch <- match(myco.tree$tip.label,
                 fulldata[,1])
data <- fulldata[spmatch,]
all(myco.tree$tip.label == data[,1])

# generate a binary tree
bitree <- multi2di(myco.tree)
dst <- bitree

# generate variable names
Mtype <- as.character(fulldata$Mycorrhizal_type)
names(Mtype) <- fulldata$Species

AM <- as.character(fulldata$AM)
names(AM) <- fulldata$Species

ERM <- as.character(fulldata$ERM)
names(ERM) <- fulldata$Species

# Mycorrhizal type
delta_T <- delta_ARD(Mtype, dst, lambda0, se, sim, thin, burn)
ar_Type <- ace(Mtype, dst, type = "discret", method = "ML", model = "ARD")$lik.anc
NE_Type  <- nentropy(ar_Type)
save(delta_T, ar_Type, NE_Type, file = "type.RData")

# AM
delta_AM <- delta_ARD(AM, dst, lambda0, se, sim, thin, burn)
ar_AM <- ace(AM, dst, type = "discret", method = "ML", model = "ARD")$lik.anc
NE_AM  <- nentropy(ar_AM)
save(delta_AM, ar_AM, NE_AM, file = "AM.RData")

#ERM (highly conserved group, using the Equal Rate (ER) model
delta_ERM <- delta_ER(ERM, dst, lambda0, se, sim, thin, burn)
ar_ERM <- ace(ERM, dst, type = "discret", method = "ML", model = "ER")$lik.anc
NE_ERM  <- nentropy(ar_ERM)
save(delta_ERM, ar_ERM, NE_ERM, file = "ERM.RData")


